@@ -35,44 +35,20 @@ class nqdm(tqdm.tqdm):
 
     
     """
+
     def __init__(self, *args, depth = 0, order = "first", enum = False, disable = False, **kwargs):
-        super().__init__(**kwargs)
+        super().__init__(disable = disable, **kwargs)
 
-        # Depth is set
-        if type(depth) == list:
-            if len(depth) != len(args):
-                depth = 0
+        self.number = len(args)
+        self.__set_depth__(depth)
+        self.__set_order__(order)
 
-        if type(depth) == int:
-            depth = [depth]*len(args)
-
-        self.depth = depth
-
-        # Order is set
-        if type(order) == list:
-            if len(order) != len(args):
-                order = "first"
-
-        if order == "first":
-            order = list(range(len(args)))
-        if order == "last":
-            order = list(range(len(args)-1, -1, -1))
-
-        self.order = order 
-        self.reverse_order = list(map(
-            lambda kv : kv[1], 
-            sorted(zip(order, range(len(order))))
-            ))
-
-        # Other variables are set
         self.enum = enum
         self.delay = 0
         self.disable = disable
 
-        # Items are ready to yield
-        args = list(map(self.__flatten__, args, depth))
+        args = list(map(self.__process__, args, self.depth))
         
-        # Length features are set
         lens = list(map(len, args))
         self.lens = [lens[order_i] for order_i in self.reverse_order]
         total = 1
@@ -80,16 +56,18 @@ class nqdm(tqdm.tqdm):
             total *= ln
         self.iterable = range(total) 
 
-        # Items are called in right order
-        get_elem = lambda point : [arg[offset] for arg, offset in zip(args, self.__ndindex__(point))]
-        args = list(map(get_elem, self.iterable))
-        if len(self.lens) == 1: args = list(map(lambda x : x[0], args))
+        args = list(map(
+            lambda point : [arg[offset] 
+            for arg, offset in zip(args, self.__offset__(point))
+            ], self.iterable))
+
+        if self.number == 0: args = []
+        if self.number == 1: args = list(map(lambda x : x[0], args))
         if enum: args = list(enumerate(args))
         self.values = args
 
     def __iter__(self):
-        if self.disable:
-            return self.values
+        if self.disable: yield self.values
         mininterval = self.mininterval
         last_print_t = self.last_print_t
         last_print_n = self.last_print_n
@@ -113,6 +91,37 @@ class nqdm(tqdm.tqdm):
             self.n = n
             self.close()
 
+    def __set_depth__(self, depth):
+        # Depth is set
+        if type(depth) == list:
+            if len(depth) != self.number:
+                depth = 0
+
+        if type(depth) == int:
+            depth = [depth]*self.number
+
+        self.depth = depth
+
+    def __set_order__(self, order):
+        # Order is set
+        if type(order) == list:
+            if len(order) != self.number:
+                order = "first"
+            if any([i not in order for i in range(self.number)]):
+                order = "first"
+
+        if order == "first":
+            order = list(range(self.number))
+        if order == "last":
+            order = list(range(self.number-1, -1, -1))
+
+        self.order = order 
+        self.reverse_order = list(map(
+            lambda kv : kv[1], 
+            sorted(zip(order, range(self.number)))
+            ))
+
+
     def __apply__(self, kind = "any"):
         functions = {
             "any" : {
@@ -174,7 +183,7 @@ class nqdm(tqdm.tqdm):
 
         return result
 
-    def __ndindex__(self, point):
+    def __offset__(self, point):
         indices = []
         for ln in self.lens:
             indices.append(point % ln)
@@ -184,26 +193,26 @@ class nqdm(tqdm.tqdm):
         return indices        
 
   
-    def __flatten__(self, arg, depth):
+    def __process__(self, arg, depth):
         arg = self.__apply__()(arg)
 
         if type(arg) in [list, dict] and depth >= 1:
-            arg = self.__flattenr__(arg, depth)
+            arg = self.__flatten__(arg, depth)
         
         arg = self.__apply__('iter')(arg)
 
         return arg
     
-    def __flattenr__(self, arg, depth):
-        arg = self.__apply__('flat')(arg)
+    def __flatten__(self, arg, depth):
         if depth < 1: return arg
+        
+        arg = self.__apply__('flat')(arg)
 
         args = []
         for arg_i in arg:
-            arg_i_ = self.__flattenr__(arg_i, depth-1)
-            if len(arg_i_) == 0:
-                args.append(arg_i) 
-            for arg_ii in arg_i_:
-                args.append(arg_ii)
-
+            arg_i = self.__flatten__(arg_i, depth-1)
+            if not hasattr(arg_i, "__len__"):
+                args.append(arg_i)
+            else:
+                args.extend(self.__apply__('iter')(arg_i))
         return args
\ No newline at end of file
